/*
 * ADXF Library
 * 
 *   Copyright (C) 2016, Jonathan Sevy <jsevy@cs.drexel.edu>
 *   
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *   of this software and associated documentation files (the "Software"), to deal
 *   in the Software without restriction, including without limitation the rights
 *   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *   copies of the Software, and to permit persons to whom the Software is
 *   furnished to do so, subject to the following conditions:
 *   
 *   The above copyright notice and this permission notice shall be included in all
 *   copies or substantial portions of the Software.
 *   
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *   SOFTWARE.
 * 
 */

package com.jsevy.adxf;

import android.graphics.Paint;



public class DXFCircle implements DXFEntity
{
    private RealPoint center;
    float radius;
    private Paint paint;
    
    
    /**
     *  * Create a circular arc from the specified parameters.
     * @param center		Center of the circle, as a RealPoint
     * @param radius		Radius of the circle
     * @param paint			The graphical Paint object specifying parameters for the arc (color, thickness)
     */
    public DXFCircle(RealPoint center, float radius, Paint paint)
    {
        this.center = new RealPoint(center);
        this.radius = radius;
        this.paint = new Paint(paint);
    }
    
    
    /**
     * Implementation of DXFObject interface method; creates DXF text representing the circle.
     */
    public String toDXFString()
    {
        String result = "0\nCIRCLE\n";
        
        // center
        result += "10\n" + center.x + "\n";
        result += "20\n" + center.y + "\n";
        result += "30\n" + center.z + "\n";
       
        // radius
        result += "40\n" + radius + "\n";
       
        // add thickness
        //result += "370\n" + paint.getStrokeWidth() + "\n";
       
        // add color number
        result += "62\n" + DXFColor.getClosestDXFColor(paint.getColor()) + "\n";
        
        return result;
    }
}