/*
 * ADXF Library
 * 
 *   Copyright (C) 2016, Jonathan Sevy <jsevy@cs.drexel.edu>
 *   
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *   of this software and associated documentation files (the "Software"), to deal
 *   in the Software without restriction, including without limitation the rights
 *   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *   copies of the Software, and to permit persons to whom the Software is
 *   furnished to do so, subject to the following conditions:
 *   
 *   The above copyright notice and this permission notice shall be included in all
 *   copies or substantial portions of the Software.
 *   
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *   SOFTWARE.
 * 
 */

package com.jsevy.adxf;

import android.graphics.Paint;



/**
 * Class representing a line segment.
 * @author jsevy
 *
 */
public class DXFLine implements DXFEntity
{
    private RealPoint start, end;
    private Paint paint;
    
    
    /**
     * Create a line segment between the specified endpoints.
     * 
     * @param start		One endpoint
     * @param end		The other endpoint
     * @param paint		The graphical Paint object specifying parameters for the line (color, thickness)
     */
    public DXFLine(RealPoint start, RealPoint end, Paint paint)
    {
        this.start = new RealPoint(start);
        this.end = new RealPoint(end);
        this.paint = new Paint(paint);
    }
    
    
    
    /**
     * Implementation of DXFObject interface method; creates DXF text representing the line segment.
     */
    public String toDXFString()
    {
        String result = "0\nLINE\n";
        
        result += "10\n" + start.x + "\n";
        result += "20\n" + start.y + "\n";
        result += "30\n" + start.z + "\n";
       
        result += "11\n" + end.x + "\n";
        result += "21\n" + end.y + "\n";
        result += "31\n" + end.z + "\n";
        
        // add thickness
        //result += "370\n" + paint.getStrokeWidth() + "\n";
       
        // add color number
        result += "62\n" + DXFColor.getClosestDXFColor(paint.getColor()) + "\n";
               
        return result;
    }
}